# ChooseALicense-cli

Bring http://choosealicense.com to your terminal. Choose a license in your terminal.

## Install

    $ pip install choosealicense-cli
    
## Usage

List all the available licenses:
    
    $ license show
    
Show the info of the specified license:

    $ license info LICENSE(e.g. mit) 
    
Show the default context for the license template:

    $ license context LICENSE(e.g. mit)
   
Generate a license:

    $ license generate LICENSE(e.g. mit)
    
Get detailed help message via `license -h` and `license show/info/context/generate -h`

## License

MIT.